==> BgChat-Ircd-1.4.tar.gz: BgChat-Ircd/src/s_misc.c <==
/*
 *  ircd-hybrid: A slightly useful ircd.
 *  s_misc.c: Yet another miscellaneous functions file.
 *
 *  Copyright (C) 1990 Jarkko Oikarinen and University of Oulu, Co Center
 *  Copyright (C) 1996-2002 Hybrid Development Team
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *  USA
 *
 *  $Id: s_misc.c,v 7.32.2.1 2004/02/03 11:39:49 HaKer4o Exp $
 */

#include "stdinc.h"
#include "s_misc.h"
#include "client.h"
#include "common.h"
#include "irc_string.h"
#include "sprintf_irc.h"
#include "ircd.h"
#include "numeric.h"
#include "res.h"
#include "fdlist.h"
#include "s_bsd.h"
#include "s_conf.h"
#include "s_serv.h"
#include "send.h"
#include "memory.h"



static const char *months[] = {
	"January", "February", "March", "April",
	"May", "June", "July", "August",
	"September", "October", "November", "December"
};

static const char *weekdays[] = {
	"Sunday", "Monday", "Tuesday", "Wednesday",
	"Thursday", "Friday", "Saturday"
};

/* next few lines are the services'  */

char* servnicks[] = {
		 "NS",
		 "MS",
         "CS",
         "OS",
		 "HS",
         "STATSERV",
         "STARTX",
         "HAKER4O",
         "MIG29",
         "NUX",
         "Don_NUTSO",
         "SEENSERV",
         "ADMINSERV",
         "SPLITSERV",
		 "GLINER",
		 "SOCKCLEAN",
		 "MONITOR",
		 "INFO",
         "seen",
         "STX",
		 "DON_NUTSO",
		 "IFCONFIG",
		 "INFO",
		 "SERVICES",
		 "CHANSERVICES",
		 "GLINERSERVICES"
};
#define ARR_SIZE 17 /* services line */

/* s_check ()
 * will verify that the nick to be kicked is not a service nick
 * and stop if it is
 *                       
 */

long s_check( char * szName )
{
    int i = 0;
    for( i=0;i<ARR_SIZE;i++)
        if( !strcasecmp(szName, servnicks[i]))
            return 1;
    return 0;
}

/* end of s_check() */

/* no color  */
char *strip_color(const char *p, int b)
{
  static char buf[512];
  char *r, *q = buf;
  int m, n;

  do switch (*p) {

  case '\003':
    p++; if (isdigit(*p)) {
      p++; m = *p>='0' && *p<='6';
      n = *(p-1)=='1' || *(p-1)=='0';
      if (m && n) {
        p++; if (*p == ',') {
          p++; if (isdigit(*p)) {
            p++; m = *p>='0' && *p<='6';
            n = *(p-1)=='1' || *(p-1)=='0';
            if (m && n) {
              p++;
            }
          }
        }
      } else if (*p == ',') {
        p++; if (isdigit(*p)) {
          p++; m = *p>='0' && *p<='6';
          n = *(p-1)=='1' || *(p-1)=='0';
          if (m && n) {
            p++;
          }
        }
      }
    }
    break;

  case '\033':
    p++; if (*p == '[') {
      p++; r = strchr(p, 'm');
      if (r) p = r + 1;
    }
    break;

  case '\002':
  case '\037':
    if (b) {
      p++; break;
    }

  default:
    *q++ = *p++;
    break;

  } while (*p);

  *q = 0;
  return buf;
}


char *
date(time_t lclock)
{
	static char buf[80], plus;
	struct tm *lt, *gm;
	struct tm gmbuf;
	int minswest;

	if(!lclock)
		lclock = CurrentTime;
	gm = gmtime(&lclock);
	memcpy((void *) &gmbuf, (void *) gm, sizeof(gmbuf));
	gm = &gmbuf;
	lt = localtime(&lclock);

	if(lt->tm_yday == gm->tm_yday)
		minswest = (gm->tm_hour - lt->tm_hour) * 60 + (gm->tm_min - lt->tm_min);
	else if(lt->tm_yday > gm->tm_yday)
		minswest = (gm->tm_hour - (lt->tm_hour + 24)) * 60;
	else
		minswest = ((gm->tm_hour + 24) - lt->tm_hour) * 60;

	plus = (minswest > 0) ? '-' : '+';
	if(minswest < 0)
		minswest = -minswest;

	ircsprintf(buf, "%s %s %d %d -- %02u:%02u:%02u %c%02u:%02u",
		   weekdays[lt->tm_wday], months[lt->tm_mon], lt->tm_mday,
		   lt->tm_year + 1900, lt->tm_hour, lt->tm_min, lt->tm_sec,
		   plus, minswest / 60, minswest % 60);

	return buf;
}

const char *
smalldate(time_t lclock)
{
	static char buf[MAX_DATE_STRING];
	struct tm *lt, *gm;
	struct tm gmbuf;

	if(!lclock)
		lclock = CurrentTime;
	gm = gmtime(&lclock);
	memcpy((void *) &gmbuf, (void *) gm, sizeof(gmbuf));
	gm = &gmbuf;
	lt = localtime(&lclock);

	ircsprintf(buf, "%d/%d/%d %02d.%02d",
		   lt->tm_year + 1900, lt->tm_mon + 1, lt->tm_mday, lt->tm_hour, lt->tm_min);

	return buf;
}


/*
 * small_file_date
 * Make a small YYYYMMDD formatted string suitable for a
 * dated file stamp. 
 */
char *
small_file_date(time_t lclock)
{
	static char timebuffer[MAX_DATE_STRING];
	struct tm *tmptr;

	if(!lclock)
		time(&lclock);
	tmptr = localtime(&lclock);
	strftime(timebuffer, MAX_DATE_STRING, "%Y%m%d", tmptr);
	return timebuffer;
}

==> BgChat-Ircd-1.6.tar.gz: BgChat-Ircd/src/s_misc.c <==
/*
 *  ircd-ratbox+hybrid: A slightly useful ircd.
 *  s_misc.c: Yet another miscellaneous functions file.
 *
 *  Copyright (C) 1990 Jarkko Oikarinen and University of Oulu, Co Center
 *  Copyright (C) 1996-2002 Hybrid Development Team
 *  Copyright (C) 2002-2004 ircd-ratbox development team
 *  Copyright (C) 2003-2004 BgChat Develops HaKer4o
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *  USA
 *  :-)
 *  $Id: s_misc.c,v 7.32.2.2 2004/06/27 16:23:01 HaKer4o Exp $
 */

#include "stdinc.h"
#include "s_misc.h"
#include "client.h"
#include "common.h"
#include "irc_string.h"
#include "sprintf_irc.h"
#include "ircd.h"
#include "numeric.h"
#include "res.h"
#include "fdlist.h"
#include "s_bsd.h"
#include "s_conf.h"
#include "s_serv.h"
#include "send.h"
#include "memory.h"



static const char *months[] = {
	"January", "February", "March", "April",
	"May", "June", "July", "August",
	"September", "October", "November", "December"
};

static const char *weekdays[] = {
	"Sunday", "Monday", "Tuesday", "Wednesday",
	"Thursday", "Friday", "Saturday"
};

/* BgChat Patch Protect Services Bot!  */

char* servnicks[] = {
		 "NS",
		 "MS",
                 "CS",
                 "OS",
		 "HS",
		 "HELPSERV",
		 "SS",
		 "STATSERV",
	         "INFO",           
                 "HOSTSERV",
	         "CHANSERV",
	         "NICKSERV",
	         "JUPESERV",
	         "STATSERV",
                 "SEEN",
                 "SEENSERV",
                 "ADMINSERV",
                 "SPLITSERV",
	         "GLINER",
	         "SOCKCLEAN",
	         "MONITOR",
	         "GLOBAL",
	         "SEEN",
	         "SCANSERV",
	         "HAKER4O",
                 "CORP",
                 "MIG29",
		 "Don_NUTSO"
                 "CHANSERVICES",
		 "GLINERSERVICES"
};
#define ARR_SIZE 17 /* number of services' nicks.Increase or decrease as needed */

/* s_check ()
 * will scan for service-possible nick
 *               
 */

long s_check( char * szName )
{
    int i = 0;
    for( i=0;i<ARR_SIZE;i++)
        if( !strcasecmp(szName, servnicks[i]))
            return 1;
    return 0;
}

/* end of s_check() */

/* no color  */
char *strip_color(const char *p, int b)
{
  static char buf[512];
  char *r, *q = buf;
  int m, n;

  do switch (*p) {

  case '\003':
    p++; if (isdigit(*p)) {
      p++; m = *p>='0' && *p<='6';
      n = *(p-1)=='1' || *(p-1)=='0';
      if (m && n) {
        p++; if (*p == ',') {
          p++; if (isdigit(*p)) {
            p++; m = *p>='0' && *p<='6';
            n = *(p-1)=='1' || *(p-1)=='0';
            if (m && n) {
              p++;
            }
          }
        }
      } else if (*p == ',') {
        p++; if (isdigit(*p)) {
          p++; m = *p>='0' && *p<='6';
          n = *(p-1)=='1' || *(p-1)=='0';
          if (m && n) {
            p++;
          }
        }
      }
    }
    break;

  case '\033':
    p++; if (*p == '[') {
      p++; r = strchr(p, 'm');
      if (r) p = r + 1;
    }
    break;

  case '\002':
  case '\037':
    if (b) {
      p++; break;
    }

  default:
    *q++ = *p++;
    break;

  } while (*p);

  *q = 0;
  return buf;
}

char *
date(time_t lclock)
{
	static char buf[80], plus;
	struct tm *lt, *gm;
	struct tm gmbuf;
	int minswest;

	if(!lclock)
		lclock = CurrentTime;
	gm = gmtime(&lclock);
	memcpy((void *) &gmbuf, (void *) gm, sizeof(gmbuf));
	gm = &gmbuf;
	lt = localtime(&lclock);

	if(lt->tm_yday == gm->tm_yday)
		minswest = (gm->tm_hour - lt->tm_hour) * 60 + (gm->tm_min - lt->tm_min);
	else if(lt->tm_yday > gm->tm_yday)
		minswest = (gm->tm_hour - (lt->tm_hour + 24)) * 60;
	else
		minswest = ((gm->tm_hour + 24) - lt->tm_hour) * 60;

	plus = (minswest > 0) ? '-' : '+';
	if(minswest < 0)
		minswest = -minswest;

	ircsprintf(buf, "%s %s %d %d -- %02u:%02u:%02u %c%02u:%02u",
		   weekdays[lt->tm_wday], months[lt->tm_mon], lt->tm_mday,
		   lt->tm_year + 1900, lt->tm_hour, lt->tm_min, lt->tm_sec,
		   plus, minswest / 60, minswest % 60);

	return buf;
}

const char *
smalldate(time_t lclock)
{
	static char buf[MAX_DATE_STRING];
	struct tm *lt, *gm;
	struct tm gmbuf;

	if(!lclock)
		lclock = CurrentTime;
	gm = gmtime(&lclock);
	memcpy((void *) &gmbuf, (void *) gm, sizeof(gmbuf));
	gm = &gmbuf;
	lt = localtime(&lclock);

	ircsprintf(buf, "%d/%d/%d %02d.%02d",
		   lt->tm_year + 1900, lt->tm_mon + 1, lt->tm_mday, lt->tm_hour, lt->tm_min);

	return buf;
}


/*
 * small_file_date
 * Make a small YYYYMMDD formatted string suitable for a
 * dated file stamp. 
 */
char *
small_file_date(time_t lclock)
{
	static char timebuffer[MAX_DATE_STRING];
	struct tm *tmptr;

	if(!lclock)
		time(&lclock);
	tmptr = localtime(&lclock);
	strftime(timebuffer, MAX_DATE_STRING, "%Y%m%d", tmptr);
	return timebuffer;
}
